<?php
/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package banca
 */

/**
 * Theme Options
 */
global $banca_opt;
$is_back_to_top_btn_switcher = banca_opt('is_back_to_top_btn_switcher', '1');
$copyright_text = banca_opt('copyright_txt', esc_html__('© 2022 All Rights Reserved by spider-themes', 'banca'));

$footer_style = '';
$select_custom_footer_opt = banca_opt('footer_style');
$select_custom_footer_page = function_exists('get_field') ? get_field('select_custom_footer') : '';

if ($select_custom_footer_page) {
    $footer_style = new WP_Query(array(
        'post_type' => 'footer',
        'posts_per_page' => -1,
        'p' => $select_custom_footer_page,
    ));
} elseif ($select_custom_footer_opt) {
    $footer_style = new WP_Query(array(
        'post_type' => 'footer',
        'posts_per_page' => -1,
        'p' => $select_custom_footer_opt,
    ));
}

if (is_404()) {
    echo '';
} else {
    if ($footer_style != '') {
        if ($footer_style->have_posts()) {
            while ($footer_style->have_posts()) : $footer_style->the_post();
                the_content();
            endwhile;
            wp_reset_postdata();
        }
    } else {
        ?>
        <footer class="footer footer-3">
            <?php
            $is_preset_footer = isset($banca_opt['is_footer_columns_preset']) ? $banca_opt['is_footer_columns_preset'] : '';
            $is_preset_footer = $is_preset_footer == '1' ? ' preset_footer' : '';

            if (is_active_sidebar('footer_widgets') && (!class_exists('EazyDocs'))) {
                ?>
                <div class="footer-top pt-lg-130 pb-lg-115 pt-105 pb-105">
                    <div class="container">
                        <div class="row<?php echo esc_attr($is_preset_footer) ?>">
                            <?php dynamic_sidebar('footer_widgets') ?>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
            <!-- copyright area -->
            <div class="copyright pt-25 pb-25">
                <div class="container">
                    <div class="row align-items-center">
                        <?php
                        if (class_exists('ReduxFrameworkPlugin')) {
                            ?>
                            <div class="col-lg-3 text-center text-lg-start">
                                <a href="<?php echo esc_url(home_url('/')) ?>" class="p-0 m-0 footer_logo">
                                    <?php
                                    if (isset($banca_opt['footer_main_logo']['url'])) {
                                        // Normal Logo
                                        $main_logo = isset($banca_opt['footer_main_logo'] ['url']) ? $banca_opt['footer_main_logo'] ['url'] : '';
                                        $retina_logo = isset($banca_opt['footer_retina_logo'] ['url']) ? $banca_opt['footer_retina_logo'] ['url'] : '';

                                        $logo_srcset = !empty($retina_logo) ? "srcset='$retina_logo 2x'" : '';
                                        $logo_srcset_sticky = !empty($retina_sticky_logo) ? "srcset='$retina_sticky_logo 2x'" : '';
                                        ?>
                                        <img class="main"
                                             src="<?php echo esc_url($main_logo); ?>" <?php echo wp_kses_post($logo_srcset) ?>
                                             alt="<?php bloginfo('name'); ?>">
                                        <?php
                                    } else {
                                        echo '<h3>' . get_bloginfo('name') . '</h3>';
                                    }
                                    ?>
                                </a>
                            </div>
                            <div class="col-lg-5 text-center my-3 my-sm-0">
                                <div class="copyright-text">
                                    <?php echo banca_kses_post($copyright_text) ?>
                                </div>
                            </div>
                            <div class="col-lg-4 text-center text-lg-end ">
                                <div class="social-button">
                                    <?php Banca_Helper()->social_links() ?>
                                </div>
                            </div>
                            <?php
                        } else {
                            ?>
                            <div class="col-lg-12 text-center">
                                <div class="copyright-text">
                                    <?php echo banca_kses_post($copyright_text) ?>
                                </div>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                </div>
            </div>
        </footer>
        <?php
    }

}

?>
<!-- Back to top button -->
<a id="back-to-top" title="Back to Top"></a>

<?php wp_footer(); ?>
</div> <!--Body Wrapper-->
</body>
</html>