<?php
// Theme settings options
$opt = get_option('banca_opt' );

// Image sizes
add_image_size('banca_690x418', 690, 418, true); // Blog Post Thumbnails
add_image_size('banca_320x208', 320, 208, true); // Blog Related Post Thumbnails

// add category nick names in body and post class
function banca_post_class( $classes ) {
    global $post;
    if ( !has_post_thumbnail() ) {
        $classes[] = 'no-post-thumbnail';
    }
    if ( is_sticky() && !in_array('sticky', $classes) ) {
        $classes[] = 'sticky';
    }
    return $classes;
}
add_filter( 'post_class', 'banca_post_class' );


/**
 * Body classes
 */
add_filter( 'body_class', function($classes) {
    $opt = get_option('banca_opt' );
    $has_menu = has_nav_menu('main_menu') ? '' : 'has_not_menu';

    $classes[] = $has_menu;

    return $classes;
});

/**
 * Show post excerpt by default
 * @param $user_login
 * @param $user
 */
function banca_show_post_excerpt( $user_login, $user ) {
    $unchecked = get_user_meta( $user->ID, 'metaboxhidden_post', true );
    $key = is_array($unchecked) ? array_search( 'postexcerpt', $unchecked ) : FALSE;
    if ( FALSE !== $key ) {
        array_splice( $unchecked, $key, 1 );
        update_user_meta( $user->ID, 'metaboxhidden_post', $unchecked );
    }
}
add_action( 'wp_login', 'banca_show_post_excerpt', 10, 2 );


// filter to replace class on reply link
add_filter('comment_reply_link', function($class){
    $class = str_replace("class='comment-reply-link", "class='comment_reply", $class);
    return $class;
});

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function banca_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'banca_pingback_header' );

// Move the comment field to bottom
add_filter( 'comment_form_fields', function ( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
});

// Remove WordPress admin bar default CSS
add_action('get_header', function() {
    remove_action('wp_head', '_admin_bar_bump_cb' );
});


// Elementor post type support
function banca_add_cpt_support() {

    //if exists, assign to $cpt_support var
    $cpt_support = get_option( 'elementor_cpt_support' );

    //check if option DOESN'T exist in db
    if ( ! $cpt_support ) {
        $cpt_support = [ 'page', 'post' ]; //create array of our default supported post types
        update_option( 'elementor_cpt_support', $cpt_support ); //write it to the database
    }

    //otherwise do nothing, portfolio already exists in elementor_cpt_support option
}
add_action( 'after_switch_theme', 'banca_add_cpt_support' );

// Color Picker Issue solution
if( is_admin() ){
	add_action( 'wp_default_scripts', 'banca_default_custom_scripts' );
	function banca_default_custom_scripts( $scripts ) {
		$scripts->add( 'wp-color-picker', "/wp-admin/js/color-picker.js", array( 'iris' ), false, 1 );
		did_action( 'init' ) && $scripts->localize(
			'wp-color-picker',
			'wpColorPickerL10n',
			array(
				'clear'            => esc_html__( 'Clear', 'banca' ),
				'clearAriaLabel'   => esc_html__( 'Clear color', 'banca' ),
				'defaultString'    => esc_html__( 'Default', 'banca' ),
				'defaultAriaLabel' => esc_html__( 'Select default color', 'banca' ),
				'pick'             => esc_html__( 'Select Color', 'banca' ),
				'defaultLabel'     => esc_html__( 'Color value', 'banca' ),
			)
		);
	}
}


// Wrap up the category count in span tag
add_filter( 'wp_list_categories', function($links) {
    $links = str_replace('</a> (', '<span>(', $links);
    $links = str_replace(')', ')</span> </a>', $links);
    return $links;
});

// Wrap up the Archive count in span tag
add_filter( 'get_archives_link', function($links) {
    $links = str_replace('</a>&nbsp;(', '<span>(', $links);
    $links = str_replace(')', ')</span> </a>', $links);
    return $links;
});


// Remove auto p from Contact Form 7 shortcode output
add_filter( 'wpcf7_autop_or_not', function() {
    return false;
});
